@@ -1,4 +1,4 @@
-pub use tsify_macros::Tsify;
+pub use tsify_macros::{tsify, Tsify};
 
 pub trait Tsify {
     const DECL: &'static str;
